# Testing Your Models

**NOTE:** This documentation is a Work in Progress.

Writing tests that use a Redis OM model requires some setup. For now, review the tests in the redis-om-python project for examples.
